@@ -1,14 +1,16 @@
 use std::{env, process};
 
-use log::LevelFilter;
+use log::Level;
 
 pub struct Args {
-    pub log_level: LevelFilter,
+    pub log_level: Level,
+    pub config_path: Option<String>,
 }
 
 impl Args {
     pub fn from_cli() -> Args {
-        let mut log_level: LevelFilter = LevelFilter::Warn;
+        let mut log_level = Level::Warn;
+        let mut config_path = None;
 
         let mut args = env::args().skip(1);
         while let Some(arg) = args.next() {
@@ -27,17 +29,21 @@ FLAGS
         Display a description of this program.
 
     --log-level
-        Either \"error\", \"warn\", \"info\", \"debug\". Uses \"warn\" by default"
+        Either \"error\", \"warn\", \"info\", \"debug\". Uses \"warn\" by default
+        
+    -c, --config
+        Specifies the config file to use.
+        "
                     );
                     process::exit(0);
                 }
                 "--log-level" => {
                     if let Some(level) = args.next() {
                         log_level = match &level[..] {
-                            "error" => LevelFilter::Error,
-                            "warn" => LevelFilter::Warn,
-                            "info" => LevelFilter::Info,
-                            "debug" => LevelFilter::Debug,
+                            "error" => Level::Error,
+                            "warn" => Level::Warn,
+                            "info" => Level::Info,
+                            "debug" => Level::Debug,
                             _ => {
                                 eprintln!("Invalid logging option: {}", level);
                                 process::exit(1);
@@ -48,6 +54,14 @@ FLAGS
                         process::exit(1);
                     }
                 }
+                "-c" | "--config" => {
+                    if let Some(path) = args.next() {
+                        config_path = Some(String::from(path));
+                    } else {
+                        eprintln!("No path given");
+                        process::exit(1);
+                    }
+                }
                 _ => {
                     eprintln!("Did not recognize \"{}\" as an option", arg);
                     process::exit(1);
@@ -55,6 +69,9 @@ FLAGS
             }
         }
 
-        return Args { log_level };
+        return Args {
+            log_level,
+            config_path,
+        };
     }
 }
